# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with bootstrap
%bcond_with gcj_support
%bcond_without repolib

%define section free

%define repodir %{_javadir}/repository.jboss.com/sun-javacc/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

Name:           javacc
Version:        5.0
Release:        5%{?dist}
Epoch:          0
Summary:        Parser/scanner generator for java
License:        BSD
URL:            https://javacc.dev.java.net/
Group:          Development/Java
Source0:        javacc-5.0src.tar.gz
Source1:        javacc.sh
Source2:        jjdoc.sh
Source3:        jjtree.sh
Source4:        javacc-component-info.xml
Patch0:         javacc-generated-files.patch
Patch1:         javacc-pom.patch
Patch2:         javacc-javacc-source.patch
Requires:       jpackage-utils
BuildRequires:  ant
%if %without bootstrap
BuildRequires:  javacc
%endif
BuildRequires:  java-devel
BuildRequires:  junit
%if %with repolib
BuildRequires:  apache-commons-parent
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-deploy
BuildRequires:  mojo-maven2-plugin-cobertura
BuildRequires:  mojo-maven2-plugin-javacc
%endif
%if %with gcj_support
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description 
Java Compiler Compiler (JavaCC) is the most popular parser generator for use
with Java applications. A parser generator is a tool that reads a grammar
specification and converts it to a Java program that can recognize matches to
the grammar. In addition to the parser generator itself, JavaCC provides other
standard capabilities related to parser generation such as tree building (via
a tool called JJTree included with JavaCC), actions, debugging, etc.

%package manual
Summary:        Manual for %{name}
Group:          Development/Java

%description manual
Manual for %{name}.

%package demo
Summary:        Examples for %{name}
Group:          Development/Java

%description demo
Examples for %{name}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n %{name}
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}
%if %without bootstrap
%{__ln_s} %{_javadir}/javacc.jar bootstrap/javacc.jar
%else
%patch0 -p1
%endif
%patch1 -p0
%patch2 -p0

%{__ln_s} %(%{_bindir}/build-classpath junit) lib/junit3.8.1/junit.jar

%build
export CLASSPATH=
export OPT_JAR_LIST=:
%{ant} -Dversion=%{version}

%install
%{__rm} -rf %{buildroot}

%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p bin/lib/%{name}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%{__ln_s} %{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

%{__mkdir_p} %{buildroot}%{_bindir}
%{__cp} -p %{SOURCE1} %{buildroot}%{_bindir}/javacc
%{__cp} -p %{SOURCE2} %{buildroot}%{_bindir}/jjdoc
%{__cp} -p %{SOURCE3} %{buildroot}%{_bindir}/jjtree
%{__mkdir_p} %{buildroot}%{_datadir}/%{name}
%{__cp} -pr examples %{buildroot}%{_datadir}/%{name}

install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -pm 644 pom.xml $RPM_BUILD_ROOT/%{_datadir}/maven2/poms/JPP-%{name}.pom

%add_to_maven_depmap net.java.dev.javacc javacc %{version} JPP %{name}

%if %with repolib
%{__mkdir_p} %{buildroot}%{repodir}
%{__mkdir_p} %{buildroot}%{repodirlib}
%{__install} -p -m 0644 %{SOURCE4} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__mkdir_p} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE0} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE1} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE2} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{SOURCE3} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{PATCH0} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{PATCH1} %{buildroot}%{repodirsrc}
%{__install} -p -m 0644 %{PATCH2} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom %{buildroot}%{repodirlib}/javacc.pom
%{__cp} -p %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/javacc.jar
%endif

%if %with repolib
%{_bindir}/mvn-jpp deploy:deploy-file -DpomFile=%{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom -Dfile=%{buildroot}%{_javadir}/%{name}-%{version}.jar \
    -Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew -Dversion=%{version}
# FIXME: Bug in maven when a previous version is also in the local repo
%define previous_version 4.2
(mkdir -p  %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/net/java/dev/javacc/javacc/%{version}
cp -prf %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/net/java/dev/javacc/javacc/%{previous_version}/* %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/net/java/dev/javacc/javacc/%{version}/
pushd %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/net/java/dev/javacc/javacc/%{version}/
for i in *-%{previous_version}*; do mv $i `echo $i | sed -e 's/-%{previous_version}/-%{version}/;'`; done
popd
rm -rf %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/net/java/dev/javacc/javacc/%{previous_version}) || :
%endif

%if %with gcj_support
%{_bindir}/aot-compile-rpm
%endif

%clean
%{__rm} -rf %{buildroot}

%if %with gcj_support
%post
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi

%postun
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc LICENSE README
%attr(0755,root,root) %{_bindir}/javacc
%attr(0755,root,root) %{_bindir}/jjdoc
%attr(0755,root,root) %{_bindir}/jjtree
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %with gcj_support
%dir %{_libdir}/gcj/%{name}
%{_libdir}/gcj/%{name}/javacc-%{version}.jar.db
%{_libdir}/gcj/%{name}/javacc-%{version}.jar.so
%endif

%files demo
%defattr(0644,root,root,0755)
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*

%files manual
%defattr(0644,root,root,0755)
%doc www/*

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*/
%{_javadir}/repository.jboss.com
%endif

%changelog
* Thu Dec 23 2010 David Walluck <dwalluck@redhat.com> 0:5.0-5
- build as non-bootstrap

* Thu Dec 23 2010 David Walluck <dwalluck@redhat.com> 0:5.0-4
- 5.0

* Mon Jan 12 2008 David Walluck <dwalluck@redhat.com> 0:4.0-5
- disable bootstrap by default

* Mon Jan 12 2008 David Walluck <dwalluck@redhat.com> 0:4.0-4
- add bootstrap mode
- add repolib

* Tue Jul 18 2006 Matthew Wringe <mwringe at redhat.com> - 0:4.0-3jpp
- Added missing build requires of ant-junit and junit
- Changed directory locations to use rpm macros
- Added conditional native compiling

* Thu Apr 20 2006 Fernando Nasser <fnasser@redhat.com> - 0:4.0-2jpp
- First JPP 1.7 build

* Fri Mar 31 2006 Sebastiano Vigna <vigna at acm.org> - 0:4.0-1jpp
- Updated to 4.0

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:3.2-2jpp
- Rebuild with ant-1.6.2

* Fri Jan 30 2004 Sebastiano Vigna <vigna at acm.org> 0:3.2-1jpp
- First JPackage version
